# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Code(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'description': 'str',
        'code_range': 'str',
        'match_column_name': 'str',
        'match_column_value': 'str',
        'hierarchy_level': 'float',
        'parent_code_id': 'str',
        'parent_code': 'Code',
        'children_codes': 'list[Code]',
        'timeline_code_filters': 'list[TimelineCodeFilter]',
        'outcome_codes': 'list[OutcomeCode]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'code_range': 'codeRange',
        'match_column_name': 'matchColumnName',
        'match_column_value': 'matchColumnValue',
        'hierarchy_level': 'hierarchyLevel',
        'parent_code_id': 'parentCodeId',
        'parent_code': 'parentCode',
        'children_codes': 'childrenCodes',
        'timeline_code_filters': 'timelineCodeFilters',
        'outcome_codes': 'outcomeCodes',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, id=None, name=None, type=None, description=None, code_range=None, match_column_name=None, match_column_value=None, hierarchy_level=None, parent_code_id=None, parent_code=None, children_codes=None, timeline_code_filters=None, outcome_codes=None, created_at=None, updated_at=None, version=None):  # noqa: E501
        """Code - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._type = None
        self._description = None
        self._code_range = None
        self._match_column_name = None
        self._match_column_value = None
        self._hierarchy_level = None
        self._parent_code_id = None
        self._parent_code = None
        self._children_codes = None
        self._timeline_code_filters = None
        self._outcome_codes = None
        self._created_at = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.name = name
        self.type = type
        if description is not None:
            self.description = description
        self.code_range = code_range
        self.match_column_name = match_column_name
        self.match_column_value = match_column_value
        self.hierarchy_level = hierarchy_level
        if parent_code_id is not None:
            self.parent_code_id = parent_code_id
        if parent_code is not None:
            self.parent_code = parent_code
        if children_codes is not None:
            self.children_codes = children_codes
        if timeline_code_filters is not None:
            self.timeline_code_filters = timeline_code_filters
        if outcome_codes is not None:
            self.outcome_codes = outcome_codes
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this Code.  # noqa: E501


        :return: The id of this Code.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Code.


        :param id: The id of this Code.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Code.  # noqa: E501


        :return: The name of this Code.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Code.


        :param name: The name of this Code.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this Code.  # noqa: E501


        :return: The type of this Code.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Code.


        :param type: The type of this Code.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def description(self):
        """Gets the description of this Code.  # noqa: E501


        :return: The description of this Code.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Code.


        :param description: The description of this Code.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def code_range(self):
        """Gets the code_range of this Code.  # noqa: E501


        :return: The code_range of this Code.  # noqa: E501
        :rtype: str
        """
        return self._code_range

    @code_range.setter
    def code_range(self, code_range):
        """Sets the code_range of this Code.


        :param code_range: The code_range of this Code.  # noqa: E501
        :type: str
        """
        if code_range is None:
            raise ValueError("Invalid value for `code_range`, must not be `None`")  # noqa: E501

        self._code_range = code_range

    @property
    def match_column_name(self):
        """Gets the match_column_name of this Code.  # noqa: E501


        :return: The match_column_name of this Code.  # noqa: E501
        :rtype: str
        """
        return self._match_column_name

    @match_column_name.setter
    def match_column_name(self, match_column_name):
        """Sets the match_column_name of this Code.


        :param match_column_name: The match_column_name of this Code.  # noqa: E501
        :type: str
        """
        if match_column_name is None:
            raise ValueError("Invalid value for `match_column_name`, must not be `None`")  # noqa: E501

        self._match_column_name = match_column_name

    @property
    def match_column_value(self):
        """Gets the match_column_value of this Code.  # noqa: E501


        :return: The match_column_value of this Code.  # noqa: E501
        :rtype: str
        """
        return self._match_column_value

    @match_column_value.setter
    def match_column_value(self, match_column_value):
        """Sets the match_column_value of this Code.


        :param match_column_value: The match_column_value of this Code.  # noqa: E501
        :type: str
        """
        if match_column_value is None:
            raise ValueError("Invalid value for `match_column_value`, must not be `None`")  # noqa: E501

        self._match_column_value = match_column_value

    @property
    def hierarchy_level(self):
        """Gets the hierarchy_level of this Code.  # noqa: E501


        :return: The hierarchy_level of this Code.  # noqa: E501
        :rtype: float
        """
        return self._hierarchy_level

    @hierarchy_level.setter
    def hierarchy_level(self, hierarchy_level):
        """Sets the hierarchy_level of this Code.


        :param hierarchy_level: The hierarchy_level of this Code.  # noqa: E501
        :type: float
        """
        if hierarchy_level is None:
            raise ValueError("Invalid value for `hierarchy_level`, must not be `None`")  # noqa: E501

        self._hierarchy_level = hierarchy_level

    @property
    def parent_code_id(self):
        """Gets the parent_code_id of this Code.  # noqa: E501


        :return: The parent_code_id of this Code.  # noqa: E501
        :rtype: str
        """
        return self._parent_code_id

    @parent_code_id.setter
    def parent_code_id(self, parent_code_id):
        """Sets the parent_code_id of this Code.


        :param parent_code_id: The parent_code_id of this Code.  # noqa: E501
        :type: str
        """

        self._parent_code_id = parent_code_id

    @property
    def parent_code(self):
        """Gets the parent_code of this Code.  # noqa: E501


        :return: The parent_code of this Code.  # noqa: E501
        :rtype: Code
        """
        return self._parent_code

    @parent_code.setter
    def parent_code(self, parent_code):
        """Sets the parent_code of this Code.


        :param parent_code: The parent_code of this Code.  # noqa: E501
        :type: Code
        """

        self._parent_code = parent_code

    @property
    def children_codes(self):
        """Gets the children_codes of this Code.  # noqa: E501


        :return: The children_codes of this Code.  # noqa: E501
        :rtype: list[Code]
        """
        return self._children_codes

    @children_codes.setter
    def children_codes(self, children_codes):
        """Sets the children_codes of this Code.


        :param children_codes: The children_codes of this Code.  # noqa: E501
        :type: list[Code]
        """

        self._children_codes = children_codes

    @property
    def timeline_code_filters(self):
        """Gets the timeline_code_filters of this Code.  # noqa: E501


        :return: The timeline_code_filters of this Code.  # noqa: E501
        :rtype: list[TimelineCodeFilter]
        """
        return self._timeline_code_filters

    @timeline_code_filters.setter
    def timeline_code_filters(self, timeline_code_filters):
        """Sets the timeline_code_filters of this Code.


        :param timeline_code_filters: The timeline_code_filters of this Code.  # noqa: E501
        :type: list[TimelineCodeFilter]
        """

        self._timeline_code_filters = timeline_code_filters

    @property
    def outcome_codes(self):
        """Gets the outcome_codes of this Code.  # noqa: E501


        :return: The outcome_codes of this Code.  # noqa: E501
        :rtype: list[OutcomeCode]
        """
        return self._outcome_codes

    @outcome_codes.setter
    def outcome_codes(self, outcome_codes):
        """Sets the outcome_codes of this Code.


        :param outcome_codes: The outcome_codes of this Code.  # noqa: E501
        :type: list[OutcomeCode]
        """

        self._outcome_codes = outcome_codes

    @property
    def created_at(self):
        """Gets the created_at of this Code.  # noqa: E501


        :return: The created_at of this Code.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Code.


        :param created_at: The created_at of this Code.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Code.  # noqa: E501


        :return: The updated_at of this Code.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Code.


        :param updated_at: The updated_at of this Code.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this Code.  # noqa: E501


        :return: The version of this Code.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Code.


        :param version: The version of this Code.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Code, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Code):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Timeline(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'type': 'str',
        'stage': 'str',
        'evidence_start_at': 'datetime',
        'outcome_end_at': 'datetime',
        'evidence_period': 'float',
        'delay_period': 'float',
        'timeline_results': 'list[str]',
        'intervention_period': 'float',
        'athena_execution_id': 'str',
        'outcome_period': 'float',
        'intervention_ratio': 'float',
        'timeline_uri': 'str',
        'aggregation': 'str',
        'project_id': 'str',
        'model_id': 'str',
        'intervention_id': 'str',
        'train_timeline_id': 'str',
        'impactability_timeline_id': 'str',
        'outcome_queries': 'list[str]',
        'model_jobs': 'list[ModelJob]',
        'timeline_code_filter_groups': 'list[TimelineCodeFilterGroup]',
        'timeline_feature_filter_groups': 'list[TimelineFeatureFilterGroup]',
        'feature_sub_categories': 'list[str]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'stage': 'stage',
        'evidence_start_at': 'evidenceStartAt',
        'outcome_end_at': 'outcomeEndAt',
        'evidence_period': 'evidencePeriod',
        'delay_period': 'delayPeriod',
        'timeline_results': 'timelineResults',
        'intervention_period': 'interventionPeriod',
        'athena_execution_id': 'athenaExecutionId',
        'outcome_period': 'outcomePeriod',
        'intervention_ratio': 'interventionRatio',
        'timeline_uri': 'timelineUri',
        'aggregation': 'aggregation',
        'project_id': 'projectId',
        'model_id': 'modelId',
        'intervention_id': 'interventionId',
        'train_timeline_id': 'trainTimelineId',
        'impactability_timeline_id': 'impactabilityTimelineId',
        'outcome_queries': 'outcomeQueries',
        'model_jobs': 'modelJobs',
        'timeline_code_filter_groups': 'timelineCodeFilterGroups',
        'timeline_feature_filter_groups': 'timelineFeatureFilterGroups',
        'feature_sub_categories': 'featureSubCategories',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, stage=None, evidence_start_at=None, outcome_end_at=None, evidence_period=None, delay_period=None, timeline_results=None, intervention_period=None, athena_execution_id=None, outcome_period=None, intervention_ratio=None, timeline_uri=None, aggregation=None, project_id=None, model_id=None, intervention_id=None, train_timeline_id=None, impactability_timeline_id=None, outcome_queries=None, model_jobs=None, timeline_code_filter_groups=None, timeline_feature_filter_groups=None, feature_sub_categories=None, created_at=None, updated_at=None, version=None):  # noqa: E501
        """Timeline - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._type = None
        self._stage = None
        self._evidence_start_at = None
        self._outcome_end_at = None
        self._evidence_period = None
        self._delay_period = None
        self._timeline_results = None
        self._intervention_period = None
        self._athena_execution_id = None
        self._outcome_period = None
        self._intervention_ratio = None
        self._timeline_uri = None
        self._aggregation = None
        self._project_id = None
        self._model_id = None
        self._intervention_id = None
        self._train_timeline_id = None
        self._impactability_timeline_id = None
        self._outcome_queries = None
        self._model_jobs = None
        self._timeline_code_filter_groups = None
        self._timeline_feature_filter_groups = None
        self._feature_sub_categories = None
        self._created_at = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.type = type
        self.stage = stage
        self.evidence_start_at = evidence_start_at
        self.outcome_end_at = outcome_end_at
        self.evidence_period = evidence_period
        self.delay_period = delay_period
        if timeline_results is not None:
            self.timeline_results = timeline_results
        if intervention_period is not None:
            self.intervention_period = intervention_period
        if athena_execution_id is not None:
            self.athena_execution_id = athena_execution_id
        self.outcome_period = outcome_period
        if intervention_ratio is not None:
            self.intervention_ratio = intervention_ratio
        if timeline_uri is not None:
            self.timeline_uri = timeline_uri
        self.aggregation = aggregation
        self.project_id = project_id
        self.model_id = model_id
        if intervention_id is not None:
            self.intervention_id = intervention_id
        if train_timeline_id is not None:
            self.train_timeline_id = train_timeline_id
        if impactability_timeline_id is not None:
            self.impactability_timeline_id = impactability_timeline_id
        if outcome_queries is not None:
            self.outcome_queries = outcome_queries
        if model_jobs is not None:
            self.model_jobs = model_jobs
        if timeline_code_filter_groups is not None:
            self.timeline_code_filter_groups = timeline_code_filter_groups
        if timeline_feature_filter_groups is not None:
            self.timeline_feature_filter_groups = timeline_feature_filter_groups
        if feature_sub_categories is not None:
            self.feature_sub_categories = feature_sub_categories
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this Timeline.  # noqa: E501


        :return: The id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Timeline.


        :param id: The id of this Timeline.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this Timeline.  # noqa: E501


        :return: The type of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Timeline.


        :param type: The type of this Timeline.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def stage(self):
        """Gets the stage of this Timeline.  # noqa: E501


        :return: The stage of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this Timeline.


        :param stage: The stage of this Timeline.  # noqa: E501
        :type: str
        """
        if stage is None:
            raise ValueError("Invalid value for `stage`, must not be `None`")  # noqa: E501

        self._stage = stage

    @property
    def evidence_start_at(self):
        """Gets the evidence_start_at of this Timeline.  # noqa: E501


        :return: The evidence_start_at of this Timeline.  # noqa: E501
        :rtype: datetime
        """
        return self._evidence_start_at

    @evidence_start_at.setter
    def evidence_start_at(self, evidence_start_at):
        """Sets the evidence_start_at of this Timeline.


        :param evidence_start_at: The evidence_start_at of this Timeline.  # noqa: E501
        :type: datetime
        """
        if evidence_start_at is None:
            raise ValueError("Invalid value for `evidence_start_at`, must not be `None`")  # noqa: E501

        self._evidence_start_at = evidence_start_at

    @property
    def outcome_end_at(self):
        """Gets the outcome_end_at of this Timeline.  # noqa: E501


        :return: The outcome_end_at of this Timeline.  # noqa: E501
        :rtype: datetime
        """
        return self._outcome_end_at

    @outcome_end_at.setter
    def outcome_end_at(self, outcome_end_at):
        """Sets the outcome_end_at of this Timeline.


        :param outcome_end_at: The outcome_end_at of this Timeline.  # noqa: E501
        :type: datetime
        """
        if outcome_end_at is None:
            raise ValueError("Invalid value for `outcome_end_at`, must not be `None`")  # noqa: E501

        self._outcome_end_at = outcome_end_at

    @property
    def evidence_period(self):
        """Gets the evidence_period of this Timeline.  # noqa: E501


        :return: The evidence_period of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._evidence_period

    @evidence_period.setter
    def evidence_period(self, evidence_period):
        """Sets the evidence_period of this Timeline.


        :param evidence_period: The evidence_period of this Timeline.  # noqa: E501
        :type: float
        """
        if evidence_period is None:
            raise ValueError("Invalid value for `evidence_period`, must not be `None`")  # noqa: E501

        self._evidence_period = evidence_period

    @property
    def delay_period(self):
        """Gets the delay_period of this Timeline.  # noqa: E501


        :return: The delay_period of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._delay_period

    @delay_period.setter
    def delay_period(self, delay_period):
        """Sets the delay_period of this Timeline.


        :param delay_period: The delay_period of this Timeline.  # noqa: E501
        :type: float
        """
        if delay_period is None:
            raise ValueError("Invalid value for `delay_period`, must not be `None`")  # noqa: E501

        self._delay_period = delay_period

    @property
    def timeline_results(self):
        """Gets the timeline_results of this Timeline.  # noqa: E501


        :return: The timeline_results of this Timeline.  # noqa: E501
        :rtype: list[str]
        """
        return self._timeline_results

    @timeline_results.setter
    def timeline_results(self, timeline_results):
        """Sets the timeline_results of this Timeline.


        :param timeline_results: The timeline_results of this Timeline.  # noqa: E501
        :type: list[str]
        """

        self._timeline_results = timeline_results

    @property
    def intervention_period(self):
        """Gets the intervention_period of this Timeline.  # noqa: E501


        :return: The intervention_period of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._intervention_period

    @intervention_period.setter
    def intervention_period(self, intervention_period):
        """Sets the intervention_period of this Timeline.


        :param intervention_period: The intervention_period of this Timeline.  # noqa: E501
        :type: float
        """

        self._intervention_period = intervention_period

    @property
    def athena_execution_id(self):
        """Gets the athena_execution_id of this Timeline.  # noqa: E501


        :return: The athena_execution_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._athena_execution_id

    @athena_execution_id.setter
    def athena_execution_id(self, athena_execution_id):
        """Sets the athena_execution_id of this Timeline.


        :param athena_execution_id: The athena_execution_id of this Timeline.  # noqa: E501
        :type: str
        """

        self._athena_execution_id = athena_execution_id

    @property
    def outcome_period(self):
        """Gets the outcome_period of this Timeline.  # noqa: E501


        :return: The outcome_period of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._outcome_period

    @outcome_period.setter
    def outcome_period(self, outcome_period):
        """Sets the outcome_period of this Timeline.


        :param outcome_period: The outcome_period of this Timeline.  # noqa: E501
        :type: float
        """
        if outcome_period is None:
            raise ValueError("Invalid value for `outcome_period`, must not be `None`")  # noqa: E501

        self._outcome_period = outcome_period

    @property
    def intervention_ratio(self):
        """Gets the intervention_ratio of this Timeline.  # noqa: E501


        :return: The intervention_ratio of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._intervention_ratio

    @intervention_ratio.setter
    def intervention_ratio(self, intervention_ratio):
        """Sets the intervention_ratio of this Timeline.


        :param intervention_ratio: The intervention_ratio of this Timeline.  # noqa: E501
        :type: float
        """

        self._intervention_ratio = intervention_ratio

    @property
    def timeline_uri(self):
        """Gets the timeline_uri of this Timeline.  # noqa: E501


        :return: The timeline_uri of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._timeline_uri

    @timeline_uri.setter
    def timeline_uri(self, timeline_uri):
        """Sets the timeline_uri of this Timeline.


        :param timeline_uri: The timeline_uri of this Timeline.  # noqa: E501
        :type: str
        """

        self._timeline_uri = timeline_uri

    @property
    def aggregation(self):
        """Gets the aggregation of this Timeline.  # noqa: E501


        :return: The aggregation of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._aggregation

    @aggregation.setter
    def aggregation(self, aggregation):
        """Sets the aggregation of this Timeline.


        :param aggregation: The aggregation of this Timeline.  # noqa: E501
        :type: str
        """
        if aggregation is None:
            raise ValueError("Invalid value for `aggregation`, must not be `None`")  # noqa: E501

        self._aggregation = aggregation

    @property
    def project_id(self):
        """Gets the project_id of this Timeline.  # noqa: E501


        :return: The project_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Timeline.


        :param project_id: The project_id of this Timeline.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def model_id(self):
        """Gets the model_id of this Timeline.  # noqa: E501


        :return: The model_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this Timeline.


        :param model_id: The model_id of this Timeline.  # noqa: E501
        :type: str
        """
        if model_id is None:
            raise ValueError("Invalid value for `model_id`, must not be `None`")  # noqa: E501

        self._model_id = model_id

    @property
    def intervention_id(self):
        """Gets the intervention_id of this Timeline.  # noqa: E501


        :return: The intervention_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._intervention_id

    @intervention_id.setter
    def intervention_id(self, intervention_id):
        """Sets the intervention_id of this Timeline.


        :param intervention_id: The intervention_id of this Timeline.  # noqa: E501
        :type: str
        """

        self._intervention_id = intervention_id

    @property
    def train_timeline_id(self):
        """Gets the train_timeline_id of this Timeline.  # noqa: E501


        :return: The train_timeline_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._train_timeline_id

    @train_timeline_id.setter
    def train_timeline_id(self, train_timeline_id):
        """Sets the train_timeline_id of this Timeline.


        :param train_timeline_id: The train_timeline_id of this Timeline.  # noqa: E501
        :type: str
        """

        self._train_timeline_id = train_timeline_id

    @property
    def impactability_timeline_id(self):
        """Gets the impactability_timeline_id of this Timeline.  # noqa: E501


        :return: The impactability_timeline_id of this Timeline.  # noqa: E501
        :rtype: str
        """
        return self._impactability_timeline_id

    @impactability_timeline_id.setter
    def impactability_timeline_id(self, impactability_timeline_id):
        """Sets the impactability_timeline_id of this Timeline.


        :param impactability_timeline_id: The impactability_timeline_id of this Timeline.  # noqa: E501
        :type: str
        """

        self._impactability_timeline_id = impactability_timeline_id

    @property
    def outcome_queries(self):
        """Gets the outcome_queries of this Timeline.  # noqa: E501


        :return: The outcome_queries of this Timeline.  # noqa: E501
        :rtype: list[str]
        """
        return self._outcome_queries

    @outcome_queries.setter
    def outcome_queries(self, outcome_queries):
        """Sets the outcome_queries of this Timeline.


        :param outcome_queries: The outcome_queries of this Timeline.  # noqa: E501
        :type: list[str]
        """

        self._outcome_queries = outcome_queries

    @property
    def model_jobs(self):
        """Gets the model_jobs of this Timeline.  # noqa: E501


        :return: The model_jobs of this Timeline.  # noqa: E501
        :rtype: list[ModelJob]
        """
        return self._model_jobs

    @model_jobs.setter
    def model_jobs(self, model_jobs):
        """Sets the model_jobs of this Timeline.


        :param model_jobs: The model_jobs of this Timeline.  # noqa: E501
        :type: list[ModelJob]
        """

        self._model_jobs = model_jobs

    @property
    def timeline_code_filter_groups(self):
        """Gets the timeline_code_filter_groups of this Timeline.  # noqa: E501


        :return: The timeline_code_filter_groups of this Timeline.  # noqa: E501
        :rtype: list[TimelineCodeFilterGroup]
        """
        return self._timeline_code_filter_groups

    @timeline_code_filter_groups.setter
    def timeline_code_filter_groups(self, timeline_code_filter_groups):
        """Sets the timeline_code_filter_groups of this Timeline.


        :param timeline_code_filter_groups: The timeline_code_filter_groups of this Timeline.  # noqa: E501
        :type: list[TimelineCodeFilterGroup]
        """

        self._timeline_code_filter_groups = timeline_code_filter_groups

    @property
    def timeline_feature_filter_groups(self):
        """Gets the timeline_feature_filter_groups of this Timeline.  # noqa: E501


        :return: The timeline_feature_filter_groups of this Timeline.  # noqa: E501
        :rtype: list[TimelineFeatureFilterGroup]
        """
        return self._timeline_feature_filter_groups

    @timeline_feature_filter_groups.setter
    def timeline_feature_filter_groups(self, timeline_feature_filter_groups):
        """Sets the timeline_feature_filter_groups of this Timeline.


        :param timeline_feature_filter_groups: The timeline_feature_filter_groups of this Timeline.  # noqa: E501
        :type: list[TimelineFeatureFilterGroup]
        """

        self._timeline_feature_filter_groups = timeline_feature_filter_groups

    @property
    def feature_sub_categories(self):
        """Gets the feature_sub_categories of this Timeline.  # noqa: E501


        :return: The feature_sub_categories of this Timeline.  # noqa: E501
        :rtype: list[str]
        """
        return self._feature_sub_categories

    @feature_sub_categories.setter
    def feature_sub_categories(self, feature_sub_categories):
        """Sets the feature_sub_categories of this Timeline.


        :param feature_sub_categories: The feature_sub_categories of this Timeline.  # noqa: E501
        :type: list[str]
        """

        self._feature_sub_categories = feature_sub_categories

    @property
    def created_at(self):
        """Gets the created_at of this Timeline.  # noqa: E501


        :return: The created_at of this Timeline.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Timeline.


        :param created_at: The created_at of this Timeline.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Timeline.  # noqa: E501


        :return: The updated_at of this Timeline.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Timeline.


        :param updated_at: The updated_at of this Timeline.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this Timeline.  # noqa: E501


        :return: The version of this Timeline.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Timeline.


        :param version: The version of this Timeline.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Timeline, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Timeline):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'type': 'str',
        'config': 'object',
        'execution_id': 'str',
        'message': 'str',
        'summary_data': 'object',
        'schema': 'object',
        'status': 'str',
        'timeline_id': 'str',
        'project_id': 'str',
        'environment_id': 'str',
        'model_dataset_id': 'str',
        'project': 'Project',
        'timeline': 'Timeline',
        'environment': 'Environment',
        'events': 'list[ModelJobEvent]',
        'endpoints': 'list[ModelEndpoint]',
        'model_dataset': 'list[ModelDataset]',
        'model_job_output_features': 'list[ModelJobOutputFeature]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'config': 'config',
        'execution_id': 'executionId',
        'message': 'message',
        'summary_data': 'summaryData',
        'schema': 'schema',
        'status': 'status',
        'timeline_id': 'timelineId',
        'project_id': 'projectId',
        'environment_id': 'environmentId',
        'model_dataset_id': 'modelDatasetId',
        'project': 'project',
        'timeline': 'timeline',
        'environment': 'environment',
        'events': 'events',
        'endpoints': 'endpoints',
        'model_dataset': 'modelDataset',
        'model_job_output_features': 'modelJobOutputFeatures',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, config=None, execution_id=None, message=None, summary_data=None, schema=None, status=None, timeline_id=None, project_id=None, environment_id=None, model_dataset_id=None, project=None, timeline=None, environment=None, events=None, endpoints=None, model_dataset=None, model_job_output_features=None, created_at=None, updated_at=None, version=None):  # noqa: E501
        """ModelJob - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._type = None
        self._config = None
        self._execution_id = None
        self._message = None
        self._summary_data = None
        self._schema = None
        self._status = None
        self._timeline_id = None
        self._project_id = None
        self._environment_id = None
        self._model_dataset_id = None
        self._project = None
        self._timeline = None
        self._environment = None
        self._events = None
        self._endpoints = None
        self._model_dataset = None
        self._model_job_output_features = None
        self._created_at = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.type = type
        if config is not None:
            self.config = config
        if execution_id is not None:
            self.execution_id = execution_id
        if message is not None:
            self.message = message
        if summary_data is not None:
            self.summary_data = summary_data
        if schema is not None:
            self.schema = schema
        if status is not None:
            self.status = status
        if timeline_id is not None:
            self.timeline_id = timeline_id
        self.project_id = project_id
        if environment_id is not None:
            self.environment_id = environment_id
        if model_dataset_id is not None:
            self.model_dataset_id = model_dataset_id
        if project is not None:
            self.project = project
        if timeline is not None:
            self.timeline = timeline
        if environment is not None:
            self.environment = environment
        if events is not None:
            self.events = events
        if endpoints is not None:
            self.endpoints = endpoints
        if model_dataset is not None:
            self.model_dataset = model_dataset
        if model_job_output_features is not None:
            self.model_job_output_features = model_job_output_features
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this ModelJob.  # noqa: E501


        :return: The id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelJob.


        :param id: The id of this ModelJob.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this ModelJob.  # noqa: E501


        :return: The type of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ModelJob.


        :param type: The type of this ModelJob.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def config(self):
        """Gets the config of this ModelJob.  # noqa: E501


        :return: The config of this ModelJob.  # noqa: E501
        :rtype: object
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this ModelJob.


        :param config: The config of this ModelJob.  # noqa: E501
        :type: object
        """

        self._config = config

    @property
    def execution_id(self):
        """Gets the execution_id of this ModelJob.  # noqa: E501


        :return: The execution_id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this ModelJob.


        :param execution_id: The execution_id of this ModelJob.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def message(self):
        """Gets the message of this ModelJob.  # noqa: E501


        :return: The message of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ModelJob.


        :param message: The message of this ModelJob.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def summary_data(self):
        """Gets the summary_data of this ModelJob.  # noqa: E501


        :return: The summary_data of this ModelJob.  # noqa: E501
        :rtype: object
        """
        return self._summary_data

    @summary_data.setter
    def summary_data(self, summary_data):
        """Sets the summary_data of this ModelJob.


        :param summary_data: The summary_data of this ModelJob.  # noqa: E501
        :type: object
        """

        self._summary_data = summary_data

    @property
    def schema(self):
        """Gets the schema of this ModelJob.  # noqa: E501


        :return: The schema of this ModelJob.  # noqa: E501
        :rtype: object
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this ModelJob.


        :param schema: The schema of this ModelJob.  # noqa: E501
        :type: object
        """

        self._schema = schema

    @property
    def status(self):
        """Gets the status of this ModelJob.  # noqa: E501


        :return: The status of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelJob.


        :param status: The status of this ModelJob.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def timeline_id(self):
        """Gets the timeline_id of this ModelJob.  # noqa: E501


        :return: The timeline_id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._timeline_id

    @timeline_id.setter
    def timeline_id(self, timeline_id):
        """Sets the timeline_id of this ModelJob.


        :param timeline_id: The timeline_id of this ModelJob.  # noqa: E501
        :type: str
        """

        self._timeline_id = timeline_id

    @property
    def project_id(self):
        """Gets the project_id of this ModelJob.  # noqa: E501


        :return: The project_id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ModelJob.


        :param project_id: The project_id of this ModelJob.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def environment_id(self):
        """Gets the environment_id of this ModelJob.  # noqa: E501


        :return: The environment_id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._environment_id

    @environment_id.setter
    def environment_id(self, environment_id):
        """Sets the environment_id of this ModelJob.


        :param environment_id: The environment_id of this ModelJob.  # noqa: E501
        :type: str
        """

        self._environment_id = environment_id

    @property
    def model_dataset_id(self):
        """Gets the model_dataset_id of this ModelJob.  # noqa: E501


        :return: The model_dataset_id of this ModelJob.  # noqa: E501
        :rtype: str
        """
        return self._model_dataset_id

    @model_dataset_id.setter
    def model_dataset_id(self, model_dataset_id):
        """Sets the model_dataset_id of this ModelJob.


        :param model_dataset_id: The model_dataset_id of this ModelJob.  # noqa: E501
        :type: str
        """

        self._model_dataset_id = model_dataset_id

    @property
    def project(self):
        """Gets the project of this ModelJob.  # noqa: E501


        :return: The project of this ModelJob.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ModelJob.


        :param project: The project of this ModelJob.  # noqa: E501
        :type: Project
        """

        self._project = project

    @property
    def timeline(self):
        """Gets the timeline of this ModelJob.  # noqa: E501


        :return: The timeline of this ModelJob.  # noqa: E501
        :rtype: Timeline
        """
        return self._timeline

    @timeline.setter
    def timeline(self, timeline):
        """Sets the timeline of this ModelJob.


        :param timeline: The timeline of this ModelJob.  # noqa: E501
        :type: Timeline
        """

        self._timeline = timeline

    @property
    def environment(self):
        """Gets the environment of this ModelJob.  # noqa: E501


        :return: The environment of this ModelJob.  # noqa: E501
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this ModelJob.


        :param environment: The environment of this ModelJob.  # noqa: E501
        :type: Environment
        """

        self._environment = environment

    @property
    def events(self):
        """Gets the events of this ModelJob.  # noqa: E501


        :return: The events of this ModelJob.  # noqa: E501
        :rtype: list[ModelJobEvent]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this ModelJob.


        :param events: The events of this ModelJob.  # noqa: E501
        :type: list[ModelJobEvent]
        """

        self._events = events

    @property
    def endpoints(self):
        """Gets the endpoints of this ModelJob.  # noqa: E501


        :return: The endpoints of this ModelJob.  # noqa: E501
        :rtype: list[ModelEndpoint]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ModelJob.


        :param endpoints: The endpoints of this ModelJob.  # noqa: E501
        :type: list[ModelEndpoint]
        """

        self._endpoints = endpoints

    @property
    def model_dataset(self):
        """Gets the model_dataset of this ModelJob.  # noqa: E501


        :return: The model_dataset of this ModelJob.  # noqa: E501
        :rtype: list[ModelDataset]
        """
        return self._model_dataset

    @model_dataset.setter
    def model_dataset(self, model_dataset):
        """Sets the model_dataset of this ModelJob.


        :param model_dataset: The model_dataset of this ModelJob.  # noqa: E501
        :type: list[ModelDataset]
        """

        self._model_dataset = model_dataset

    @property
    def model_job_output_features(self):
        """Gets the model_job_output_features of this ModelJob.  # noqa: E501


        :return: The model_job_output_features of this ModelJob.  # noqa: E501
        :rtype: list[ModelJobOutputFeature]
        """
        return self._model_job_output_features

    @model_job_output_features.setter
    def model_job_output_features(self, model_job_output_features):
        """Sets the model_job_output_features of this ModelJob.


        :param model_job_output_features: The model_job_output_features of this ModelJob.  # noqa: E501
        :type: list[ModelJobOutputFeature]
        """

        self._model_job_output_features = model_job_output_features

    @property
    def created_at(self):
        """Gets the created_at of this ModelJob.  # noqa: E501


        :return: The created_at of this ModelJob.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ModelJob.


        :param created_at: The created_at of this ModelJob.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ModelJob.  # noqa: E501


        :return: The updated_at of this ModelJob.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ModelJob.


        :param updated_at: The updated_at of this ModelJob.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this ModelJob.  # noqa: E501


        :return: The version of this ModelJob.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ModelJob.


        :param version: The version of this ModelJob.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelJob):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.swagger_client
from curia.api.swagger_client.api.platform_api import PlatformApi  # noqa: E501
from curia.api.swagger_client.rest import ApiException


class TestPlatformApi(unittest.TestCase):
    """PlatformApi unit test stubs"""

    def setUp(self):
        self.api = PlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_dataset_controller_dataset(self):
        """Test case for create_many_base_dataset_controller_dataset

        Create many Dataset  # noqa: E501
        """
        pass

    def test_create_many_base_environment_controller_environment(self):
        """Test case for create_many_base_environment_controller_environment

        Create many Environment  # noqa: E501
        """
        pass

    def test_create_many_base_intervention_controller_intervention(self):
        """Test case for create_many_base_intervention_controller_intervention

        Create many Intervention  # noqa: E501
        """
        pass

    def test_create_many_base_model_controller_model(self):
        """Test case for create_many_base_model_controller_model

        Create many Model  # noqa: E501
        """
        pass

    def test_create_many_base_model_dataset_controller_model_dataset(self):
        """Test case for create_many_base_model_dataset_controller_model_dataset

        Create many ModelDataset  # noqa: E501
        """
        pass

    def test_create_many_base_model_endpoint_controller_model_endpoint(self):
        """Test case for create_many_base_model_endpoint_controller_model_endpoint

        Create many ModelEndpoint  # noqa: E501
        """
        pass

    def test_create_many_base_model_job_controller_model_job(self):
        """Test case for create_many_base_model_job_controller_model_job

        Create many ModelJob  # noqa: E501
        """
        pass

    def test_create_many_base_organization_setting_controller_organization_setting(self):
        """Test case for create_many_base_organization_setting_controller_organization_setting

        Create many OrganizationSetting  # noqa: E501
        """
        pass

    def test_create_many_base_organizations_controller_organization(self):
        """Test case for create_many_base_organizations_controller_organization

        Create many Organization  # noqa: E501
        """
        pass

    def test_create_many_base_project_controller_project(self):
        """Test case for create_many_base_project_controller_project

        Create many Project  # noqa: E501
        """
        pass

    def test_create_many_base_project_member_controller_project_member(self):
        """Test case for create_many_base_project_member_controller_project_member

        Create many ProjectMember  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for create_many_base_timeline_code_filter_controller_timeline_code_filter

        Create many TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_controller_timeline(self):
        """Test case for create_many_base_timeline_controller_timeline

        Create many Timeline  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for create_many_base_timeline_feature_filter_controller_timeline_feature_filter

        Create many TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_create_many_base_user_favorite_controller_user_favorite(self):
        """Test case for create_many_base_user_favorite_controller_user_favorite

        Create many UserFavorite  # noqa: E501
        """
        pass

    def test_create_one_base_dataset_controller_dataset(self):
        """Test case for create_one_base_dataset_controller_dataset

        Create one Dataset  # noqa: E501
        """
        pass

    def test_create_one_base_environment_controller_environment(self):
        """Test case for create_one_base_environment_controller_environment

        Create one Environment  # noqa: E501
        """
        pass

    def test_create_one_base_intervention_controller_intervention(self):
        """Test case for create_one_base_intervention_controller_intervention

        Create one Intervention  # noqa: E501
        """
        pass

    def test_create_one_base_model_controller_model(self):
        """Test case for create_one_base_model_controller_model

        Create one Model  # noqa: E501
        """
        pass

    def test_create_one_base_model_dataset_controller_model_dataset(self):
        """Test case for create_one_base_model_dataset_controller_model_dataset

        Create one ModelDataset  # noqa: E501
        """
        pass

    def test_create_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for create_one_base_model_endpoint_controller_model_endpoint

        Create one ModelEndpoint  # noqa: E501
        """
        pass

    def test_create_one_base_model_job_controller_model_job(self):
        """Test case for create_one_base_model_job_controller_model_job

        Create one ModelJob  # noqa: E501
        """
        pass

    def test_create_one_base_organization_setting_controller_organization_setting(self):
        """Test case for create_one_base_organization_setting_controller_organization_setting

        Create one OrganizationSetting  # noqa: E501
        """
        pass

    def test_create_one_base_organizations_controller_organization(self):
        """Test case for create_one_base_organizations_controller_organization

        Create one Organization  # noqa: E501
        """
        pass

    def test_create_one_base_project_controller_project(self):
        """Test case for create_one_base_project_controller_project

        Create one Project  # noqa: E501
        """
        pass

    def test_create_one_base_project_member_controller_project_member(self):
        """Test case for create_one_base_project_member_controller_project_member

        Create one ProjectMember  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for create_one_base_timeline_code_filter_controller_timeline_code_filter

        Create one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_controller_timeline(self):
        """Test case for create_one_base_timeline_controller_timeline

        Create one Timeline  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for create_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Create one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_create_one_base_user_favorite_controller_user_favorite(self):
        """Test case for create_one_base_user_favorite_controller_user_favorite

        Create one UserFavorite  # noqa: E501
        """
        pass

    def test_dataset_controller_get_summary(self):
        """Test case for dataset_controller_get_summary

        """
        pass

    def test_dataset_controller_upload(self):
        """Test case for dataset_controller_upload

        """
        pass

    def test_delete_one_base_dataset_controller_dataset(self):
        """Test case for delete_one_base_dataset_controller_dataset

        Delete one Dataset  # noqa: E501
        """
        pass

    def test_delete_one_base_environment_controller_environment(self):
        """Test case for delete_one_base_environment_controller_environment

        Delete one Environment  # noqa: E501
        """
        pass

    def test_delete_one_base_intervention_controller_intervention(self):
        """Test case for delete_one_base_intervention_controller_intervention

        Delete one Intervention  # noqa: E501
        """
        pass

    def test_delete_one_base_model_controller_model(self):
        """Test case for delete_one_base_model_controller_model

        Delete one Model  # noqa: E501
        """
        pass

    def test_delete_one_base_model_dataset_controller_model_dataset(self):
        """Test case for delete_one_base_model_dataset_controller_model_dataset

        Delete one ModelDataset  # noqa: E501
        """
        pass

    def test_delete_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for delete_one_base_model_endpoint_controller_model_endpoint

        Delete one ModelEndpoint  # noqa: E501
        """
        pass

    def test_delete_one_base_model_job_controller_model_job(self):
        """Test case for delete_one_base_model_job_controller_model_job

        Delete one ModelJob  # noqa: E501
        """
        pass

    def test_delete_one_base_organization_setting_controller_organization_setting(self):
        """Test case for delete_one_base_organization_setting_controller_organization_setting

        Delete one OrganizationSetting  # noqa: E501
        """
        pass

    def test_delete_one_base_organizations_controller_organization(self):
        """Test case for delete_one_base_organizations_controller_organization

        Delete one Organization  # noqa: E501
        """
        pass

    def test_delete_one_base_project_controller_project(self):
        """Test case for delete_one_base_project_controller_project

        Delete one Project  # noqa: E501
        """
        pass

    def test_delete_one_base_project_member_controller_project_member(self):
        """Test case for delete_one_base_project_member_controller_project_member

        Delete one ProjectMember  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for delete_one_base_timeline_code_filter_controller_timeline_code_filter

        Delete one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_controller_timeline(self):
        """Test case for delete_one_base_timeline_controller_timeline

        Delete one Timeline  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for delete_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Delete one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_delete_one_base_user_favorite_controller_user_favorite(self):
        """Test case for delete_one_base_user_favorite_controller_user_favorite

        Delete one UserFavorite  # noqa: E501
        """
        pass

    def test_environment_controller_start(self):
        """Test case for environment_controller_start

        """
        pass

    def test_environment_controller_status(self):
        """Test case for environment_controller_status

        """
        pass

    def test_environment_controller_stop(self):
        """Test case for environment_controller_stop

        """
        pass

    def test_get_many_base_dataset_controller_dataset(self):
        """Test case for get_many_base_dataset_controller_dataset

        Retrieve many Dataset  # noqa: E501
        """
        pass

    def test_get_many_base_environment_controller_environment(self):
        """Test case for get_many_base_environment_controller_environment

        Retrieve many Environment  # noqa: E501
        """
        pass

    def test_get_many_base_intervention_controller_intervention(self):
        """Test case for get_many_base_intervention_controller_intervention

        Retrieve many Intervention  # noqa: E501
        """
        pass

    def test_get_many_base_model_controller_model(self):
        """Test case for get_many_base_model_controller_model

        Retrieve many Model  # noqa: E501
        """
        pass

    def test_get_many_base_model_dataset_controller_model_dataset(self):
        """Test case for get_many_base_model_dataset_controller_model_dataset

        Retrieve many ModelDataset  # noqa: E501
        """
        pass

    def test_get_many_base_model_endpoint_controller_model_endpoint(self):
        """Test case for get_many_base_model_endpoint_controller_model_endpoint

        Retrieve many ModelEndpoint  # noqa: E501
        """
        pass

    def test_get_many_base_model_job_controller_model_job(self):
        """Test case for get_many_base_model_job_controller_model_job

        Retrieve many ModelJob  # noqa: E501
        """
        pass

    def test_get_many_base_model_job_event_controller_model_job_event(self):
        """Test case for get_many_base_model_job_event_controller_model_job_event

        Retrieve many ModelJobEvent  # noqa: E501
        """
        pass

    def test_get_many_base_organization_setting_controller_organization_setting(self):
        """Test case for get_many_base_organization_setting_controller_organization_setting

        Retrieve many OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_many_base_organizations_controller_organization(self):
        """Test case for get_many_base_organizations_controller_organization

        Retrieve many Organization  # noqa: E501
        """
        pass

    def test_get_many_base_project_controller_project(self):
        """Test case for get_many_base_project_controller_project

        Retrieve many Project  # noqa: E501
        """
        pass

    def test_get_many_base_project_member_controller_project_member(self):
        """Test case for get_many_base_project_member_controller_project_member

        Retrieve many ProjectMember  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for get_many_base_timeline_code_filter_controller_timeline_code_filter

        Retrieve many TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_controller_timeline(self):
        """Test case for get_many_base_timeline_controller_timeline

        Retrieve many Timeline  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for get_many_base_timeline_feature_filter_controller_timeline_feature_filter

        Retrieve many TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_get_many_base_user_favorite_controller_user_favorite(self):
        """Test case for get_many_base_user_favorite_controller_user_favorite

        Retrieve many UserFavorite  # noqa: E501
        """
        pass

    def test_get_one_base_dataset_controller_dataset(self):
        """Test case for get_one_base_dataset_controller_dataset

        Retrieve one Dataset  # noqa: E501
        """
        pass

    def test_get_one_base_environment_controller_environment(self):
        """Test case for get_one_base_environment_controller_environment

        Retrieve one Environment  # noqa: E501
        """
        pass

    def test_get_one_base_intervention_controller_intervention(self):
        """Test case for get_one_base_intervention_controller_intervention

        Retrieve one Intervention  # noqa: E501
        """
        pass

    def test_get_one_base_model_controller_model(self):
        """Test case for get_one_base_model_controller_model

        Retrieve one Model  # noqa: E501
        """
        pass

    def test_get_one_base_model_dataset_controller_model_dataset(self):
        """Test case for get_one_base_model_dataset_controller_model_dataset

        Retrieve one ModelDataset  # noqa: E501
        """
        pass

    def test_get_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for get_one_base_model_endpoint_controller_model_endpoint

        Retrieve one ModelEndpoint  # noqa: E501
        """
        pass

    def test_get_one_base_model_job_controller_model_job(self):
        """Test case for get_one_base_model_job_controller_model_job

        Retrieve one ModelJob  # noqa: E501
        """
        pass

    def test_get_one_base_model_job_event_controller_model_job_event(self):
        """Test case for get_one_base_model_job_event_controller_model_job_event

        Retrieve one ModelJobEvent  # noqa: E501
        """
        pass

    def test_get_one_base_organization_setting_controller_organization_setting(self):
        """Test case for get_one_base_organization_setting_controller_organization_setting

        Retrieve one OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_one_base_organizations_controller_organization(self):
        """Test case for get_one_base_organizations_controller_organization

        Retrieve one Organization  # noqa: E501
        """
        pass

    def test_get_one_base_project_controller_project(self):
        """Test case for get_one_base_project_controller_project

        Retrieve one Project  # noqa: E501
        """
        pass

    def test_get_one_base_project_member_controller_project_member(self):
        """Test case for get_one_base_project_member_controller_project_member

        Retrieve one ProjectMember  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for get_one_base_timeline_code_filter_controller_timeline_code_filter

        Retrieve one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_controller_timeline(self):
        """Test case for get_one_base_timeline_controller_timeline

        Retrieve one Timeline  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for get_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Retrieve one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_get_one_base_user_favorite_controller_user_favorite(self):
        """Test case for get_one_base_user_favorite_controller_user_favorite

        Retrieve one UserFavorite  # noqa: E501
        """
        pass

    def test_intervention_controller_get_upload_url(self):
        """Test case for intervention_controller_get_upload_url

        """
        pass

    def test_model_controller_clone_model(self):
        """Test case for model_controller_clone_model

        """
        pass

    def test_model_endpoint_controller_invoke(self):
        """Test case for model_endpoint_controller_invoke

        """
        pass

    def test_model_endpoint_controller_start(self):
        """Test case for model_endpoint_controller_start

        """
        pass

    def test_model_endpoint_controller_status(self):
        """Test case for model_endpoint_controller_status

        """
        pass

    def test_model_endpoint_controller_stop(self):
        """Test case for model_endpoint_controller_stop

        """
        pass

    def test_model_job_controller_get_prediction_output_data(self):
        """Test case for model_job_controller_get_prediction_output_data

        """
        pass

    def test_model_job_controller_get_predictions_url(self):
        """Test case for model_job_controller_get_predictions_url

        """
        pass

    def test_model_job_controller_get_training_output_data(self):
        """Test case for model_job_controller_get_training_output_data

        """
        pass

    def test_model_job_controller_start(self):
        """Test case for model_job_controller_start

        """
        pass

    def test_model_job_controller_status(self):
        """Test case for model_job_controller_status

        """
        pass

    def test_model_job_controller_stop(self):
        """Test case for model_job_controller_stop

        """
        pass

    def test_project_controller_get_all_project_children(self):
        """Test case for project_controller_get_all_project_children

        """
        pass

    def test_project_controller_get_all_project_parents(self):
        """Test case for project_controller_get_all_project_parents

        """
        pass

    def test_replace_one_base_dataset_controller_dataset(self):
        """Test case for replace_one_base_dataset_controller_dataset

        Replace one Dataset  # noqa: E501
        """
        pass

    def test_replace_one_base_environment_controller_environment(self):
        """Test case for replace_one_base_environment_controller_environment

        Replace one Environment  # noqa: E501
        """
        pass

    def test_replace_one_base_intervention_controller_intervention(self):
        """Test case for replace_one_base_intervention_controller_intervention

        Replace one Intervention  # noqa: E501
        """
        pass

    def test_replace_one_base_model_controller_model(self):
        """Test case for replace_one_base_model_controller_model

        Replace one Model  # noqa: E501
        """
        pass

    def test_replace_one_base_model_dataset_controller_model_dataset(self):
        """Test case for replace_one_base_model_dataset_controller_model_dataset

        Replace one ModelDataset  # noqa: E501
        """
        pass

    def test_replace_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for replace_one_base_model_endpoint_controller_model_endpoint

        Replace one ModelEndpoint  # noqa: E501
        """
        pass

    def test_replace_one_base_model_job_controller_model_job(self):
        """Test case for replace_one_base_model_job_controller_model_job

        Replace one ModelJob  # noqa: E501
        """
        pass

    def test_replace_one_base_organization_setting_controller_organization_setting(self):
        """Test case for replace_one_base_organization_setting_controller_organization_setting

        Replace one OrganizationSetting  # noqa: E501
        """
        pass

    def test_replace_one_base_organizations_controller_organization(self):
        """Test case for replace_one_base_organizations_controller_organization

        Replace one Organization  # noqa: E501
        """
        pass

    def test_replace_one_base_project_controller_project(self):
        """Test case for replace_one_base_project_controller_project

        Replace one Project  # noqa: E501
        """
        pass

    def test_replace_one_base_project_member_controller_project_member(self):
        """Test case for replace_one_base_project_member_controller_project_member

        Replace one ProjectMember  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for replace_one_base_timeline_code_filter_controller_timeline_code_filter

        Replace one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_controller_timeline(self):
        """Test case for replace_one_base_timeline_controller_timeline

        Replace one Timeline  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for replace_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Replace one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_replace_one_base_user_favorite_controller_user_favorite(self):
        """Test case for replace_one_base_user_favorite_controller_user_favorite

        Replace one UserFavorite  # noqa: E501
        """
        pass

    def test_timeline_controller_build_timeline(self):
        """Test case for timeline_controller_build_timeline

        """
        pass

    def test_timeline_controller_clone_timeline(self):
        """Test case for timeline_controller_clone_timeline

        """
        pass

    def test_timeline_controller_get_timeline_status(self):
        """Test case for timeline_controller_get_timeline_status

        """
        pass

    def test_update_one_base_dataset_controller_dataset(self):
        """Test case for update_one_base_dataset_controller_dataset

        Update one Dataset  # noqa: E501
        """
        pass

    def test_update_one_base_environment_controller_environment(self):
        """Test case for update_one_base_environment_controller_environment

        Update one Environment  # noqa: E501
        """
        pass

    def test_update_one_base_intervention_controller_intervention(self):
        """Test case for update_one_base_intervention_controller_intervention

        Update one Intervention  # noqa: E501
        """
        pass

    def test_update_one_base_model_controller_model(self):
        """Test case for update_one_base_model_controller_model

        Update one Model  # noqa: E501
        """
        pass

    def test_update_one_base_model_dataset_controller_model_dataset(self):
        """Test case for update_one_base_model_dataset_controller_model_dataset

        Update one ModelDataset  # noqa: E501
        """
        pass

    def test_update_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for update_one_base_model_endpoint_controller_model_endpoint

        Update one ModelEndpoint  # noqa: E501
        """
        pass

    def test_update_one_base_model_job_controller_model_job(self):
        """Test case for update_one_base_model_job_controller_model_job

        Update one ModelJob  # noqa: E501
        """
        pass

    def test_update_one_base_organization_setting_controller_organization_setting(self):
        """Test case for update_one_base_organization_setting_controller_organization_setting

        Update one OrganizationSetting  # noqa: E501
        """
        pass

    def test_update_one_base_organizations_controller_organization(self):
        """Test case for update_one_base_organizations_controller_organization

        Update one Organization  # noqa: E501
        """
        pass

    def test_update_one_base_project_controller_project(self):
        """Test case for update_one_base_project_controller_project

        Update one Project  # noqa: E501
        """
        pass

    def test_update_one_base_project_member_controller_project_member(self):
        """Test case for update_one_base_project_member_controller_project_member

        Update one ProjectMember  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for update_one_base_timeline_code_filter_controller_timeline_code_filter

        Update one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_controller_timeline(self):
        """Test case for update_one_base_timeline_controller_timeline

        Update one Timeline  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for update_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Update one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_update_one_base_user_favorite_controller_user_favorite(self):
        """Test case for update_one_base_user_favorite_controller_user_favorite

        Update one UserFavorite  # noqa: E501
        """
        pass

    def test_user_management_controller_assign_user_permissions(self):
        """Test case for user_management_controller_assign_user_permissions

        """
        pass

    def test_user_management_controller_assign_user_roles(self):
        """Test case for user_management_controller_assign_user_roles

        """
        pass

    def test_user_management_controller_get_my_user(self):
        """Test case for user_management_controller_get_my_user

        """
        pass

    def test_user_management_controller_get_my_user_api_key(self):
        """Test case for user_management_controller_get_my_user_api_key

        """
        pass

    def test_user_management_controller_get_roles(self):
        """Test case for user_management_controller_get_roles

        """
        pass

    def test_user_management_controller_get_user(self):
        """Test case for user_management_controller_get_user

        """
        pass

    def test_user_management_controller_get_users(self):
        """Test case for user_management_controller_get_users

        """
        pass

    def test_user_management_controller_invite_user(self):
        """Test case for user_management_controller_invite_user

        """
        pass

    def test_user_management_controller_remove_user_permission(self):
        """Test case for user_management_controller_remove_user_permission

        """
        pass

    def test_user_management_controller_remove_user_roles(self):
        """Test case for user_management_controller_remove_user_roles

        """
        pass

    def test_user_management_controller_request_password_reset(self):
        """Test case for user_management_controller_request_password_reset

        """
        pass

    def test_user_management_controller_update_my_user(self):
        """Test case for user_management_controller_update_my_user

        """
        pass

    def test_user_management_controller_update_user(self):
        """Test case for user_management_controller_update_user

        """
        pass

    def test_user_management_controller_update_user_metadata(self):
        """Test case for user_management_controller_update_user_metadata

        """
        pass


if __name__ == '__main__':
    unittest.main()
